Type: Package
Package: bs4Dash
Title: A 'Bootstrap 4' Version of 'shinydashboard'
Version: 2.3.5
Authors@R: c(
    person("David", "Granjon", , "dgranjon@ymail.com", role = c("aut", "cre")),
    person(, "RinteRface", role = "cph"),
    person(, "Almasaeed Studio", role = c("ctb", "cph"),
           comment = "AdminLTE3 theme for Bootstrap 4"),
    person("Winston", "Chang", role = c("ctb", "cph"),
           comment = "Utils functions from shinydashboard")
  )
Maintainer: David Granjon <dgranjon@ymail.com>
Description: Make 'Bootstrap 4' Shiny dashboards. Use the full power of
    'AdminLTE3', a dashboard template built on top of 'Bootstrap 4'
    <https://github.com/ColorlibHQ/AdminLTE>.
License: GPL (>= 2) | file LICENSE
URL: https://github.com/RinteRface/bs4Dash,
        https://bs4dash.rinterface.com/
BugReports: https://github.com/RinteRface/bs4Dash/issues
Depends: R (>= 2.10)
Imports: bslib (>= 0.2.4), cli, fresh, htmltools (>= 0.5.1.1), httpuv
        (>= 1.5.2), httr, jsonlite (>= 0.9.16), lifecycle, rlang (>=
        1.1.0), shiny (>= 1.6.0), waiter (>= 0.2.3)
Suggests: DT, golem, knitr, rmarkdown, testthat (>= 3.0.0), thematic
        (>= 0.1.2)
VignetteBuilder: knitr
RdMacros: lifecycle
Encoding: UTF-8
RoxygenNote: 7.3.2
Collate: 'feedbacks.R' 'useful-items.R' 'tabs.R' 'render-functions.R'
        'cards.R' 'dashboardSidebar.R' 'dashboardBody.R'
        'dashboardFooter.R' 'dashboardControlbar.R' 'dashboardHeader.R'
        'dashboardPage.R' 'aliases.R' 'auto-color.R'
        'bs4Dash-package.r' 'bs4DashGallery.R' 'deps.R' 'grid.R'
        'import-standalone-obj-type.R'
        'import-standalone-types-check.R' 'inputs.R' 'skinSelector.R'
        'utils.R' 'zzz.R'
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-08-25 10:33:25 UTC; davidgranjon
Author: David Granjon [aut, cre],
  RinteRface [cph],
  Almasaeed Studio [ctb, cph] (AdminLTE3 theme for Bootstrap 4),
  Winston Chang [ctb, cph] (Utils functions from shinydashboard)
Repository: CRAN
Date/Publication: 2025-08-25 11:10:14 UTC
Built: R 4.6.0; ; 2026-04-26 15:51:07 UTC; unix
