---
title: "Improved boxes"
author: "David Granjon"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Improved boxes}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include=FALSE}
library(bslib)
```
  
## Boxes on Steroids!
  
### The box state
`box()` is without any doubt a central component of `{bs4Dash}`. Thanks to the AdminLTE API, `{bs4Dash}` 
is able to provide more interactivity to this component. For instance, you may:
  
  - Know the state of any box at any time. This state captures different parameters such as
  collapsed, closed, maximized.
  - Toggle a box.
  - Close/Restore a box.
  - update box properties: title, status, solidHeader, background, width, height, 
  collapsible, closable and maximizable.
  
To benefit from that feature, one must pass the _id_ parameter and access it on the server side 
with `input$<id>`. Let's consider an example:

```{r boxAPI-code, eval=TRUE, echo=FALSE}
card(
  bs4Dash:::create_link_iframe(bs4Dash:::shinylive_links["inst/examples/vignettes-demos/box-api"]),
  full_screen = TRUE,
  style = "margin: 0 auto; float: none;"
)
```

We call the `updateBox()` function, specifying the action to accomplish:

- toggle
- remove
- restore
- update

Knowing the state of a box significantly opens new possibilities within the application, thereby increasing interactivity. 
If you want to know more about the underlying mechanisms, have a look at the box widget [documentation](https://adminlte.io/docs/3.1//javascript/card-widget.html). 

### Box components
With `{bs4Dash}`, you may embed labels, a sidebar and dropdown menus in the 
box header. 

```{r boxTools, echo=FALSE, fig.cap='Box Tools. From left to right: boxLabel, boxDropdown, collapsible and closable buttons, boxSidebar trigger.', fig.align = 'center', out.width='50%'}
knitr::include_graphics("figures/boxTools.png")
``` 

#### Box Labels
`boxLabel()` are passed in the `box()` _label_ slot. They typically contain number or a short text.

#### Box Sidebar
`boxSidebar()` is invoked through the `box()` sidebar parameter. The sidebar has an _id_ allowing to programmatically
toggle it on the server side with `updateBoxSidebar()`. This component is generally used to contain input element that you 
do not want to show in the box, while the box body generally contains visualizations such as plots or tables. 
`boxSidebar()` is highly customizable as one may change the background color, the width and the icon trigger, 
the latter displayed on the very right side of the box header, as depicted in Figure \@ref(fig:boxTools). 
Below is an example showing how to set up the sidebar and toggle it.

```{r boxSidebar-code, eval=TRUE, echo=FALSE}
card(
  bs4Dash:::create_link_iframe(bs4Dash:::shinylive_links["inst/examples/vignettes-demos/box-sidebar"]),
  full_screen = TRUE,
  style = "margin: 0 auto; float: none;"
)
```

What is the interest of being able to toggle the sidebar on the server? Image you want
to open the sidebar as soon as the user clicks on a specific action button.

#### Box Dropdown
`boxDropdown()` is a super powerful tool since all dropdown items may behave like action buttons.
This feature allows to seamlessly add interactivity to the box component and gather features in one place.
In the example below, clicking on the first item triggers a `toast()`.

```{r boxDropdown-code, eval=TRUE, echo=FALSE}
card(
  bs4Dash:::create_link_iframe(bs4Dash:::shinylive_links["inst/examples/vignettes-demos/box-dropdown"]),
  full_screen = TRUE,
  style = "margin: 0 auto; float: none;"
)
```

### Other Boxes
`{bs4Dash}` provides more box components to be able to adapt to various situations. What if you wanted
to create a box with comments, with social content?

#### userBox

`userBox()` is intended to highlight user profiles. It has many common parameters with `box()` and overall the same layout.
The 2 major diffences between `box()` and `userBox()` are:

- The ability to add a user image in the box header.
- Optionally add a background image in the box header.
- The _color_ parameter is only applied to the box header.

Additionally, you may also select 2 types: centered image or left-aligned image.

The __title__ argument expects a `userDescription()`:

```{r user-description, eval=FALSE}
userDescription(
  title = "Nadia Carmichael",
  subtitle = "lead Developer",
  type = 2,
  image = "https://adminlte.io/themes/AdminLTE/dist/img/user7-128x128.jpg",
)
```

`userBox()` is also entirely updatable from the server side, as it is built on top the `box()` function:
```{r userBox-code, eval=TRUE, echo=FALSE}
card(
  bs4Dash:::create_link_iframe(bs4Dash:::shinylive_links["inst/examples/vignettes-demos/userBox"]),
  full_screen = TRUE,
  style = "margin: 0 auto; float: none;"
)
```

#### socialBox

A `socialBox()` is dedicated to contain events, comments, anything related to people. 
The __title__ parameter hosts `userBlock()`:

```{r user-block, eval=FALSE}
userBlock(
  image = "https://adminlte.io/themes/AdminLTE/dist/img/user4-128x128.jpg",
  title = "Social Box",
  subtitle = "example-01.05.2018"
)
```

Elements like `attachmentBlock()` and `userMessages()` are a good fit with this component. 
The `...` slot may hosts multiple `boxComment`, consisting in user comments. 
Right now, there is no programmatic way (understand no __update__ function is available) to handle them but a future release of `{bs4Dash}` 
will obviously fill this gap. The app below shows a combination of multiple elements in a 
`socialBox()`:

```{r socialBox-code, eval=TRUE, echo=FALSE}
card(
  bs4Dash:::create_link_iframe(bs4Dash:::shinylive_links["inst/examples/vignettes-demos/socialBox"]),
  full_screen = TRUE,
  style = "margin: 0 auto; float: none;"
)
```
